| Title: | Preprocessing functions for REMIND and other energy models (no landuse data) |
|---|---|
| Description: | Preprocessing functions for REMIND and other energy models (buildings, transport, industry) not using landuse data. |
| Authors: | Falk Benke [aut, cre] |
| Maintainer: | Falk Benke <[email protected]> |
| License: | LGPL-3 |
| Version: | 0.3.3 |
| Built: | 2026-06-27 10:35:40 UTC |
| Source: | https://github.com/pik-piam/mrcommonsenergy |
Calculates buildings-related energy flows from the IEA energy balances. 'output_EDGE_buildings' is a key input to EDGE-Buildings providing the historic final energy demand from buildings. 'output_EDGE' does the same for buildings and industry together.
calcIOEdgeBuildings( subtype = c("output_EDGE", "output_EDGE_buildings"), ieaVersion = c("default", "latest") )calcIOEdgeBuildings( subtype = c("output_EDGE", "output_EDGE_buildings"), ieaVersion = c("default", "latest") )
subtype |
Data subtype. See default argument for possible values. |
ieaVersion |
Release version of IEA data, either 'default' (vetted and used in REMIND) or 'latest'. |
IEA data as MAgPIE object aggregated to country level
Pascal Sauer, Anastasis Giannousakis, Robin Hasse
## Not run: a <- calcOutput("IOEdgeBuildings", subtype = "output_EDGE_buildings") ## End(Not run)## Not run: a <- calcOutput("IOEdgeBuildings", subtype = "output_EDGE_buildings") ## End(Not run)
Read-in European Environment Agency (EEA) data on ETS emissions as magclass object
convertEEA_EuropeanEnvironmentAgency(x, subtype)convertEEA_EuropeanEnvironmentAgency(x, subtype)
x |
MAgPIE object to be converted |
subtype |
data subtype. Either "ETS", "historical", "projections", or "projections-detailed" |
magpie object of European Environment Agency (EEA) ETS emissions (GtCO2)
Renato Rodrigues, Robin Hasse
## Not run: a <- readSource(type = "EEA_EuropeanEnvironmentAgency", subtype = "ETS") ## End(Not run)## Not run: a <- readSource(type = "EEA_EuropeanEnvironmentAgency", subtype = "ETS") ## End(Not run)
Converts EU Reference Scenario magpie object into appropriate form for the REMIND model
convertEU_ReferenceScenario(x, subtype)convertEU_ReferenceScenario(x, subtype)
x |
EU Reference Scenario magpie object derived from readEU_ReferenceScenario function |
subtype |
data subtype. Either "techAssump.*", "2016" or "2020" |
converted EU Reference Scenario magpie object
Renato Rodrigues, Falk Benke, Robin Hasse
## Not run: test <- readSource("EU_ReferenceScenario", subtype = "2020", convert = TRUE) ## End(Not run)## Not run: test <- readSource("EU_ReferenceScenario", subtype = "2020", convert = TRUE) ## End(Not run)
Read Eurostat historical emissions (env_air_gge)
convertEurostat(x, subtype)convertEurostat(x, subtype)
x |
MAgPIE object to be converted |
subtype |
'emissions' for original Eurostat emissions split, 'MACCemi' for MACC historical emissions, or 'sectorEmi' for sector specific emissions, or 'latest' for most up-to-date data |
A MAgPIE object containing the Eurostat historical emissions (MtCO2)
Renato Rodrigues
## Not run: a <- convertEurostat(x, subtype = "emissions") ## End(Not run)## Not run: a <- convertEurostat(x, subtype = "emissions") ## End(Not run)
Convert IEA energy data to data on ISO country level.
convertIEA(x, subtype)convertIEA(x, subtype)
x |
MAgPIE object containing IEA values at IEA mixed country-region resolution |
subtype |
data subtype. Either "EnergyBalances", "EnergyBalances-latest", or "Emissions" |
IEA data as MAgPIE object aggregated to country level
Anastasis Giannousakis, Renato Rodrigues, Falk Benke
Missing data for EU-28 countries is added, by distributing the difference of
EU28 and the sum of country-values based on countries share in EU-28 GDP.
convertJRC_IDEES(x, subtype)convertJRC_IDEES(x, subtype)
x |
a magpie object |
subtype |
character, subtype of |
A magpie object.
Michaja Pehl, Robin Hasse
Convert UNFCCC data
convertUNFCCC(x)convertUNFCCC(x)
x |
A |
A magpie object.
Falk Benke
Read-in European Environment Agency (EEA) data on ETS emissions as magclass object
readEEA_EuropeanEnvironmentAgency(subtype)readEEA_EuropeanEnvironmentAgency(subtype)
subtype |
data subtype. Either "ETS", "ESR", "total", "sectoral", "projections", or "projections-detailed" |
magpie object of European Environment Agency (EEA) ETS emissions (GtCO2)
Renato Rodrigues, Falk Benke, Robin Hasse
## Not run: a <- readSource(type = "EEA_EuropeanEnvironmentAgency", subtype = "ETS") ## End(Not run)## Not run: a <- readSource(type = "EEA_EuropeanEnvironmentAgency", subtype = "ETS") ## End(Not run)
Read EU Reference Scenario .xlsx file as magpie object
readEU_ReferenceScenario(subtype)readEU_ReferenceScenario(subtype)
subtype |
data subtype. Either "techAssump.*", "2016" or "2020" |
magpie object of EU reference scenario data by country. Units follow REMIND report conventions and conversion factor is defined in EU_ReferenceScenario2REMIND.xlsx file.
Renato Rodrigues, Falk Benke, Robin Hasse
## Not run: test <- readSource("EU_ReferenceScenario", subtype = "2020", convert = FALSE) ## End(Not run)## Not run: test <- readSource("EU_ReferenceScenario", subtype = "2020", convert = FALSE) ## End(Not run)
Read-in Eurostat historical emissions csv files as magclass object
readEurostat(subtype = "emissions")readEurostat(subtype = "emissions")
subtype |
'emissions' for original Eurostat emissions split, 'MACCemi' for MACC historical emissions, or 'sectorEmi' for sector specific emissions, or 'latest' for most up-to-date data |
magpie object of Eurostat historical emissions (MtCO2)
Renato Rodrigues
## Not run: a <- readSource(type = "Eurostat", subtype = "emissions") ## End(Not run)## Not run: a <- readSource(type = "Eurostat", subtype = "emissions") ## End(Not run)
Read-in an IEA csv file as magpie object
readIEA(subtype)readIEA(subtype)
subtype |
data subtype. Either "EnergyBalances", "EnergyBalances-latest", or "Emissions".
|
magpie object of the IEA
Anastasis Giannousakis, Lavinia Baumstark, Renato Rodrigues, Falk Benke
## Not run: a <- readSource(type = "IEA", subtype = "EnergyBalances") ## End(Not run)## Not run: a <- readSource(type = "IEA", subtype = "EnergyBalances") ## End(Not run)
Read the IDEES data base from JRC #nolint
readJRC_IDEES(subtype)readJRC_IDEES(subtype)
subtype |
one of
|
A magpie object.
Michaja Pehl, Falk Benke, Robin Hasse
Aggregate regional data, but if regional aggregations exist, discard the automatically aggregated values and replace them with source data.
toolAggregateCustomRegs( x, agg, rel, to = NULL, removeAllAgg = TRUE, regs = "GLO" )toolAggregateCustomRegs( x, agg, rel, to = NULL, removeAllAgg = TRUE, regs = "GLO" )
x |
a magclass object in country resolution |
agg |
magclass object supplying explicit regional aggregates |
rel |
aggregation mapping for |
to |
aggregation target for |
removeAllAgg |
decide whether to exclude all aggregated data or keep those (variables/periods) that are not overwritten by data from agg object |
regs |
one or multiple names of aggregated regions to be removed/overwritten |
magclass object
Falk Benke, Pascal Weigmann
Returns the year associated with a given ieaVersion
toolGetIEAYear(ieaVersion)toolGetIEAYear(ieaVersion)
ieaVersion |
Release version of IEA data, either 'default' (vetted and used in REMIND) or 'latest'. |
Falk Benke
We assume that below a given GDP/cap level, all biomass is traditional and above a higher limit, all biomass is modern with a linear transition between the limits.
toolSplitBiomass( x, gdppop, split = "biomass", into = c("biotrad", "biomod"), dim = 3.1, limits = c(12300, 18500) )toolSplitBiomass( x, gdppop, split = "biomass", into = c("biotrad", "biomod"), dim = 3.1, limits = c(12300, 18500) )
x |
MagPIE object including biomass data |
gdppop |
MagPIE object with GDP/cap data |
split |
character, name of item to split |
into |
character vector of length two with the names of the split items |
dim |
dimension of |
limits |
numeric vector of length two with the corresponding GDP/cap limits. The default values used to be 10k and 15k USD/cap converted from 2005 to 2017 dollars. |
MagPIE object including split biomass data
Robin Hasse